@@ -507,19 +507,21 @@ class HydraPy:
         ''' use self._service_name here to enforce that only a service message '''
         ''' owner can dequeue a message '''
         res = await self._redis.rpoplpush(f'{self._redis_pre_key}:{self._service_name}:mqrecieved', f'{self._redis_pre_key}:{self._service_name}:mqinprogress')
-        return json.loads(res)
+        if res:
+            return json.loads(res)
+        return None
 
     async def mark_queue_message(self, message, completed, reason):
         ''' use self._service_name here to enforce that only a service message '''
         ''' owner can mark a message as processed '''
-        smsg = json.loads(message)
+        smsg = json.dumps(message)
         await self._redis.lrem(f'{self._redis_pre_key}:{self._service_name}:mqinprogress', -1, smsg)
         if 'bdy' in message:
             message['bdy']['reason'] = reason or 'reason not provided'
         elif 'body' in message:
             message['bdy']['reason'] = reason or 'reason not provided'
         if not completed:
-            smsg = json.loads(message)
+            smsg = json.dumps(message)
             self._redis.rpush(f'{self._redis_pre_key}:{self._service_name}:mqincomplete', smsg)
         return message
 
